Crate netgauze_bmp_service

Crate netgauze_bmp_service 

Modules

actor
BMP Actor Module
handle
Utils to handle crate::server::BmpServer lifecycle This module is heavily influenced by axum-server
server
supervisor
BMP Supervisor Module
transport
Generic Transport tooling Example

Structs

AddrInfo
Capture the address of both sides of a socket
Subscription
TaggedData
Associate a value with a tag

Functions

create_bmp_channel
new_tcp_reuse_port
Enable socket reuse and bind to a device or a VRF on selected platforms for TCP. Binding to device or VRF is supported on: MacOS and Linux.

Type Aliases

ActorId
BmpReceiver
BmpRequest
BmpSender
SubscriberId